Touch Method — Rucio 1.2 documentation

# Touch Method

class `rucio.client.touchclient.` `TouchClient`(rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=None, user_agent='rucio-clients')

  Bases: `rucio.client.baseclient.BaseClient`

  Touch client class to send a trace that can be used to update accessed_at for file or dataset DIDs

  `DIDS_BASEURL` = 'dids'
  `TRACES_BASEURL` = 'traces'
  `touch`(scope, name, rse=None)

    Sends a touch trace for a given file or dataset.

    Parameters: | scope – the scope of the file/dataset to update. name – the name of file/dataset to update. rse – optional parameter if a specific replica should be touched.
    Raises: | DataIdentifierNotFound – if given dids does not exist. RSENotFound – if rse is not None and given rse does not exist. UnsupportedDIDType – if type of the given DID is not FILE or DATASET. RucioException – if trace could not be sent successfully.